<!doctype html>

<html lang="en">
<head>
  <meta charset="utf-8">
  <title>BAC0 | http://github.com/ChristianTremblay/BAC0</title>
</head>

<body>
  {{ script|safe }}
  <div class='instructions'>
  Click on the legend labels to show or hide histories
  Refreshing the page will create runtime errors in the console
  </div>

</body>
</html>