#!/usr/bin/python
# -*- coding: utf-8 -*-
#
# Copyright (C) 2015 by Christian Tremblay, P.Eng <christian.tremblay@servisys.com>
# Licensed under LGPLv3, see file LICENSE in this source tree.
#
'''
infos.py - BAC0 Package MetaData
'''

__author__ = 'Christian Tremblay, P.Eng.'
__email__ = 'christian.tremblay@servisys.com'
__url__ = 'https://github.com/ChristianTremblay/BAC0'
__download_url__ = 'https://github.com/ChristianTremblay/BAC0/archive/master.zip'
__version__ = '0.99.920'
__license__ = 'LGPLv3'
