<!doctype html>

<html lang="en">
<head>
  <meta charset="utf-8">
  <title>BAC0 | http://github.com/ChristianTremblay/BAC0</title>
</head>

<body>
    <div>
    <H1>BAC0 - Web Interface to your Python scripts</h1>
    </div>
    <div>    
    <a href="/trends" target="_blank"><img src="/static/histories2.png" alt="Histories" width="128">Histories</a>
    <br>
    <a href="/devices"><img src="/static/devices2.png" alt="Devices" width="128">Devices</a>
    <br>
    <a href="/notes"><img src="/static/notes.png" alt="Notes for device" width="128">Notes of device</a>
    <br>
    <a href="http://bac0.readthedocs.io/en/latest/"><img src="/static/readthedocs.png" alt="Documentation" width="128">Documentation</a>
    <br>
    <a href="https://gitter.im/ChristianTremblay/BAC0"><img src="/static/gitter2.png" alt="Chat" width="128">Chat on gitter.im</a>
    <br>
    <a href="https://github.com/ChristianTremblay/BAC0"><img src="/static/GitHub-Mark.png" alt="Github" width="128">Github</a>
    <br>
    <a href="https://pythoninthebuilding.wordpress.com/"><img src="/static/wordpress.png" alt="Github" width="128">Github</a>

    </div>    
</body>
<footer>
Icons by <a href=https://www.iconfinder.com/laurareen>Laura Reen</a>
</footer>
</html>